@@ -21,11 +21,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-Wstrict-prototypes -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 '
-           '-pipe -fstack-protector-strong -fno-plt -march=armv6 '
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+           '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
+           '-mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt -march=armv6 '
            '-mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong '
-           '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
-           '-fstack-protector-strong -fno-plt',
+           '-fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -35,7 +35,8 @@ build_time_vars = {'ABIFLAGS': 'm',
                      '-fstack-protector-strong -fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
-                            '-Wno-missing-field-initializers',
+                            '-Wno-missing-field-initializers '
+                            '-Wno-cast-function-type',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
@@ -50,8 +51,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python/src/Python-3.6.5/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.6.5/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.6.6/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.6.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -561,7 +562,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -595,24 +596,25 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-Wstrict-prototypes -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 '
-              '-pipe -fstack-protector-strong -fno-plt -march=armv6 '
-              '-mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong '
-              '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+              '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
+              '-mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt '
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
               '-fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers',
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wno-cast-function-type',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -Wstrict-prototypes -march=armv6 -mfloat-abi=hard '
-                   '-mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt '
-                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                   '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                   '-fstack-protector-strong -fno-plt -march=armv6 '
+                   '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
                    '-fstack-protector-strong -fno-plt -march=armv6 '
                    '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
                    '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -I. -I./Include '
-                   '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC '
-                   '-DPy_BUILD_CORE',
+                   '-Wno-missing-field-initializers -Wno-cast-function-type '
+                   '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
@@ -625,7 +627,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.6',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -666,9 +668,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.6 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.5 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.6.6 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -693,8 +695,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.6.5',
- 'abs_srcdir': '/build/python/src/Python-3.6.5',
+ 'abs_builddir': '/build/python/src/Python-3.6.6',
+ 'abs_srcdir': '/build/python/src/Python-3.6.6',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
